@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Nestoria::Search::Result;
 BEGIN {
-  $WebService::Nestoria::Search::Result::VERSION = '1.019001';
+  $WebService::Nestoria::Search::Result::VERSION = '1.020000';
 }
 
 =head1 NAME
@@ -12,7 +12,7 @@ WebService::Nestoria::Search::Result - Container object for a WebService::Nestor
 
 =head1 VERSION
 
-version 1.019001
+version 1.020000
 
 Contains all the information received about a single property listing and many functions for outputting the information.
 
@@ -49,6 +49,7 @@ as follows:
     get_price_formatted
     get_price_high
     get_price_low
+    get_price_coldrent
     get_title
     get_summary
     get_bedroom_number
@@ -88,6 +89,7 @@ sub get_price_currency            { shift->{data}{listing}{price_currency}
 sub get_price_formatted           { shift->{data}{listing}{price_formatted};              }
 sub get_price_high                { shift->{data}{listing}{price_high};                   }
 sub get_price_low                 { shift->{data}{listing}{price_low};                    }
+sub get_price_coldrent            { shift->{data}{listing}{price_coldrent};               }
 sub get_title                     { shift->{data}{listing}{title}                         }
 sub get_summary                   { shift->{data}{listing}{summary}                       }
 sub get_bedroom_number            { shift->{data}{listing}{bedroom_number}                }
